==> org.eclipse.jubula.rc.swing.source_2.2.0.201309271544.jar: org/eclipse/jubula/rc/swing/tester/adapter/JTabbedPaneAdapter.java <==
/*******************************************************************************
 * Copyright (c) 2012 BREDEX GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BREDEX GmbH - initial API and implementation 
 *******************************************************************************/
package org.eclipse.jubula.rc.swing.tester.adapter;

import javax.swing.JTabbedPane;

import org.eclipse.jubula.rc.common.driver.IRunnable;
import org.eclipse.jubula.rc.common.tester.adapter.interfaces.ITabbedComponent;

/**
 * Implementation of the Interface <code>ITabPaneAdapter</code> as a adapter for
 * the <code>JTabbedPane</code> component.
 * 
 * @author BREDEX GmbH
 * 
 */
public class JTabbedPaneAdapter extends JComponentAdapter 
    implements ITabbedComponent {
    /** The JTabbedPane on which the actions are performed. */
    private JTabbedPane m_pane;
    
    /**
     * 
     * @param objectToAdapt 
     */
    public JTabbedPaneAdapter(Object objectToAdapt) {
        super(objectToAdapt);
        m_pane = (JTabbedPane) objectToAdapt;
    }

    /**
     * {@inheritDoc}
     */
    public int getTabCount() {
        return ((Integer) getEventThreadQueuer().invokeAndWait(
                "getTabCount", new IRunnable() { //$NON-NLS-1$
                    public Object run() {
                        return new Integer(m_pane.getTabCount());
                    }
                })).intValue(); 
    }
    
    /**
     * {@inheritDoc}
     */
    public String getTitleofTab(final int index) {
        return (String) getEventThreadQueuer().invokeAndWait(
                "getTitleOfTab", new IRunnable() { //$NON-NLS-1$
                    public Object run() {
                        return m_pane.getTitleAt(index);
                    }
                });        
    }

    /**
     * {@inheritDoc}
     */
    public Object getBoundsAt(final int index) {
        
        return getEventThreadQueuer().invokeAndWait(
                "getBoundsAt", new IRunnable() { //$NON-NLS-1$
                    public Object run() {
                        return m_pane.getBoundsAt(index);
                    }
                }); 
    }

    /**
     * {@inheritDoc}
     */
    public boolean isEnabledAt(final int index) {
        return ((Boolean) getEventThreadQueuer().invokeAndWait(
                "isEnabledAt", new IRunnable() { //$NON-NLS-1$
                    public Object run() {
                        return Boolean.valueOf(m_pane.isEnabledAt(index));
                    }
                })).booleanValue(); 
    }

    /**
     * {@inheritDoc}
     */
    public int getSelectedIndex() {        
        return ((Integer) getEventThreadQueuer().invokeAndWait(
                "getSelectedIndex", new IRunnable() { //$NON-NLS-1$
                    public Object run() {
                        return new Integer(m_pane.getSelectedIndex());
                    }
                })).intValue();
    }

}

==> org.eclipse.jubula.rc.swing.source_8.0.1.201911260641.jar: org/eclipse/jubula/rc/swing/tester/adapter/JTabbedPaneAdapter.java <==
/*******************************************************************************
 * Copyright (c) 2012 BREDEX GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BREDEX GmbH - initial API and implementation 
 *******************************************************************************/
package org.eclipse.jubula.rc.swing.tester.adapter;

import java.awt.Rectangle;

import javax.swing.JTabbedPane;

import org.eclipse.jubula.rc.common.driver.IRunnable;
import org.eclipse.jubula.rc.common.tester.adapter.interfaces.ITabbedComponent;

/**
 * Implementation of the Interface <code>ITabPaneAdapter</code> as a adapter for
 * the <code>JTabbedPane</code> component.
 * 
 * @author BREDEX GmbH
 * 
 */
public class JTabbedPaneAdapter extends JComponentAdapter 
    implements ITabbedComponent {
    /** The JTabbedPane on which the actions are performed. */
    private JTabbedPane m_pane;
    
    /**
     * 
     * @param objectToAdapt 
     */
    public JTabbedPaneAdapter(Object objectToAdapt) {
        super(objectToAdapt);
        m_pane = (JTabbedPane) objectToAdapt;
    }

    /**
     * {@inheritDoc}
     */
    public int getTabCount() {
        return getEventThreadQueuer().invokeAndWait(
                "getTabCount", new IRunnable<Integer>() { //$NON-NLS-1$
                    public Integer run() {
                        return m_pane.getTabCount();
                    }
                });
    }
    
    /**
     * {@inheritDoc}
     */
    public String getTitleofTab(final int index) {
        return getEventThreadQueuer().invokeAndWait(
                "getTitleOfTab", new IRunnable<String>() { //$NON-NLS-1$
                    public String run() {
                        return m_pane.getTitleAt(index);
                    }
                });
    }

    /**
     * {@inheritDoc}
     */
    public Object getBoundsAt(final int index) {
        return getEventThreadQueuer().invokeAndWait(
                "getBoundsAt", new IRunnable<Rectangle>() { //$NON-NLS-1$
                    public Rectangle run() {
                        return m_pane.getBoundsAt(index);
                    }
                });
    }

    /**
     * {@inheritDoc}
     */
    public boolean isEnabledAt(final int index) {
        return getEventThreadQueuer().invokeAndWait(
                "isEnabledAt", new IRunnable<Boolean>() { //$NON-NLS-1$
                    public Boolean run() {
                        return m_pane.isEnabledAt(index);
                    }
                }); 
    }

    /**
     * {@inheritDoc}
     */
    public int getSelectedIndex() {
        return getEventThreadQueuer().invokeAndWait(
                "getSelectedIndex", new IRunnable<Integer>() { //$NON-NLS-1$
                    public Integer run() {
                        return m_pane.getSelectedIndex();
                    }
                });
    }
}
